@@ -1,11 +1,11 @@
 from databasetools.csv import CSVExport, CSVImport, CSV
 from databasetools.sqlite import SQLiteSyntax, SQLiteQuery, SQLiteTools
 from databasetools.dict import DictTools
-from databasetools.sql import MySQLTools
+from databasetools.sql import MySQL, MySQLTools
 from databasetools.php import PHPArray
 from databasetools.json import JSON
 from databasetools.pickle import Pickle
 
 
-__all__ = ["CSVExport", "CSVImport", "CSV", "SQLiteSyntax", "SQLiteQuery", "SQLiteTools", "DictTools", "MySQLTools",
-           "PHPArray", "JSON", "Pickle"]
+__all__ = ["CSVExport", "CSVImport", "CSV", "SQLiteSyntax", "SQLiteQuery", "SQLiteTools", "DictTools", "MySQL",
+           "MySQLTools", "PHPArray", "JSON", "Pickle"]
