@@ -1,7 +1,7 @@
-from __future__ import print_function
 import os
 import mysql.connector
 from mysql.connector import errorcode
+from tqdm import tqdm
 
 
 def get_column_value_strings(columns, query_type='insert'):
@@ -29,7 +29,7 @@ def join_columns(cols):
     return ", ".join([i for i in cols])
 
 
-class MySQLTools:
+class MySQL:
     def __init__(self, config, enable_printing=True):
         """
         Connect to MySQL database and execute queries
@@ -47,6 +47,17 @@ class MySQLTools:
         self._commit()
         self._close()
 
+    @property
+    def tables(self):
+        """Retrieve a list of tables in the connected database"""
+        statement = 'show tables'
+        return self._fetch(statement)
+
+    @property
+    def databases(self):
+        """Retrieve a list of databases that are accessible under the current connection"""
+        return self._fetch('show databases')
+
     def _connect(self, config):
         """Establish a connection with a MySQL database."""
         try:
@@ -78,8 +89,19 @@ class MySQLTools:
         """Execute a SQL query and return values."""
         # Execute statement
         self._cursor.execute(statement)
-        self._printer('\tMySQL rows successfully queried')
-        return [row for row in self._cursor]
+        rows = []
+        for row in self._cursor:
+            if len(row) == 1:
+                rows.append(row[0])
+            else:
+                rows.append(row)
+        self._printer('\tMySQL rows successfully queried', len(rows))
+
+        # Return a single item if the list only has one item
+        if len(rows) == 1:
+            return rows[0]
+        else:
+            return rows
 
     def select(self, table, cols):
         """Query only certain columns from a table and every row."""
@@ -179,6 +201,22 @@ class MySQLTools:
     #     statement = "create table " + table + " ("
     #     self._printer(statement)
 
+    def drop_table(self, table):
+        """Drop a table from the database."""
+        self._cursor.execute('DROP TABLE ' + table)
+        self._commit()
+
+    def drop_empty_tables(self):
+        """Drop all empty tables in a database."""
+        # Count number of rows
+        counts = self.count_rows_all()
+
+        # Loop through each table key and validate that rows count is not 0
+        for table, count in counts.items():
+            if count < 1:
+                # Drop table if it contains no rows
+                self.drop_table(table)
+
     def execute_sql_script(self, sql_script):
         """Execute a sql file one command at a time."""
         # Open and read the file as a single buffer
@@ -195,26 +233,54 @@ class MySQLTools:
         success = 0
 
         # Execute every command from the input file
-        for count, command in enumerate(sql_commands):
+        for command in tqdm(sql_commands, total=len(sql_commands), desc='Executing SQL Commands'):
             # This will skip and report errors
             # For example, if the tables do not yet exist, this will skip over
             # the DROP TABLE commands
             try:
                 self._cursor.execute(command)
                 self._commit()
-                self._printer(count, 'success')
                 success += 1
             except:
                 fails.append(command)
-                self._printer(count, 'fail')
 
         # Write fail commands to a text file
-        fails = [com + ';' for com in fails]
         self._printer(success, 'total successful commands')
-        self._printer(len(fails), 'total failed commands')
 
         # Dump failed commands to text file
-        txt_file = os.path.join(os.path.dirname(sql_script), 'sql fails.txt')
-        with open(txt_file) as txt:
-            txt.writelines(fails)
-        self._printer('Fail commands dumped to', txt_file)
+        if len(fails) < 1:
+            # Re-add semi-colon separator
+            fails = [com + ';' for com in fails]
+            self._printer(len(fails), 'total failed commands')
+
+            # Dump failed commands to text file in the same directory as the script
+            txt_file = os.path.join(os.path.dirname(sql_script), 'sql fails.txt')
+            with open(txt_file, 'w') as txt:
+                txt.writelines(fails)
+            self._printer('Fail commands dumped to', txt_file)
+
+    def get_schema(self, table, with_headers=False):
+        """Retrieve the database schema for a particular table."""
+        statement = 'desc ' + table
+        f = self._fetch(statement)
+
+        # If with_headers is True, insert headers to first row before returning
+        if with_headers:
+            f.insert(0, ('Type', 'Null', 'Key', 'Default', 'Extra'))
+        return f
+
+    def count_rows(self, table):
+        """Get the number of rows in a particular table"""
+        statement = 'SELECT COUNT(*) FROM ' + table
+        return self._fetch(statement)
+
+    def count_rows_all(self):
+        """Get the number of rows for every table in the database."""
+        self.enable_printing = False
+        return {table: self.count_rows(table) for table in self.tables}
+
+
+class MySQLTools(MySQL):
+    def __init__(self, config, enable_printing=True):
+        """Wrapper class for MySQL"""
+        super(MySQLTools, self).__init__(config, enable_printing)
